@@ -1,16 +1,11 @@
 .infer_file_type <- function(filename) {
 	type <- NULL;
-	if (inherits(filename, "filename")) {
+	if (is.character(filename)) {
+		filename <- as.filename(filename);
+	}
+	if (is.filename(filename)) {
 		if (!is.null(filename$ext)) {
 			type <- filename$ext[length(filename$ext)];
-		}
-	} else if (is.character(filename)) {
-		# Strip possible leading periods
-		path <- sub("^\\.+", "", filename);
-		# Determine type from file extension
-		parts <- strsplit(path, ".", fixed=TRUE)[[1]];
-		if (length(parts) > 1) {
-			type <- parts[length(parts)];
 		} else {
 			# filename has no period: assume it points to a directory
 			type <- "directory";
@@ -21,3 +16,12 @@
 
 	if (is.null(type)) NULL else tolower(type)
 }
+
+.qio_error <- function(file, type) {
+	if (missing(type)) {
+		stop("File type is not specified and could not be inferred from file: ",
+			as.character(file));
+	} else {
+		stop(sprintf("File type `%s` is not supported", type));
+	}
+}
