@@ -2,12 +2,12 @@
 #' @export
 qread.xml <- function(file, type, ...) {
 	require(XML);
-	xmlParse(file, ...)
+	XML::xmlParse(file, ...)
 }
 
 #' @method qwrite xml
 #' @export
 qwrite.xml <- function(x, file, type, ...) {
 	require(XML);
-	saveXML(x, file, ...)
+	XML::saveXML(x, file, ...)
 }
