@@ -3,7 +3,7 @@
 qread.yaml <- function(file, type, ...) {
 	require(yaml);
 
-	yaml.load_file(file, ...)
+	yaml::yaml.load_file(file, ...)
 }
 
 #' @method qwrite yaml
@@ -11,5 +11,5 @@ qread.yaml <- function(file, type, ...) {
 qwrite.yaml <- function(x, file, type, append=FALSE, ...) {
 	require(yaml);
 
-	cat(as.yaml(x, ...), sep="", file=file, append=append)
+	cat(yaml::as.yaml(x, ...), sep="", file=file, append=append)
 }
